@@ -88,8 +88,10 @@ int ReadSinoParams3DParallel(
 			Geometry_flag=1;
 			if(strcmp(fieldval_s,"parallel")==0)
 				sinoparams->Geometry = 0;
-			else if(strcmp(fieldval_s,"fan")==0)
+			else if(strcmp(fieldval_s,"fan-curved")==0)
 				sinoparams->Geometry = 1;
+			else if(strcmp(fieldval_s,"fan-flat")==0)
+				sinoparams->Geometry = 2;
 			else {
 				fprintf(stderr,"Error in %s: Geometry value \"%s\" unrecognized\n",fname,fieldval_s);
 				exit(-1);
@@ -148,7 +150,7 @@ int ReadSinoParams3DParallel(
 		fprintf(stderr,"Error in %s: \"Geometry\" field unspecified\n",fname);
 		exit(-1);
 	}
-	if(sinoparams->Geometry == 1) {
+	if(sinoparams->Geometry > 0) {
 		if(sinoparams->DistSourceDetector < 0.0 || sinoparams->Magnification < 0.0) {
 			fprintf(stderr,"Error in %s: Invalid/unspecified DistSourceDetector or Magnification\n",fname);
 			exit(-1);
@@ -354,6 +356,7 @@ void printReconParamsQGGMRF3D(struct ReconParams *reconparams)
     fprintf(stdout, " - Stop threshold for convergence                        = %.6f %%\n", reconparams->StopThreshold);
     fprintf(stdout, " - Maximum number of ICD iterations                      = %d\n", reconparams->MaxIterations);
     fprintf(stdout, " - Positivity constraint flag                            = %d\n", reconparams->Positivity);
+    fprintf(stdout, " - Relaxation Factor                                     = %.2f\n", reconparams->RelaxFactor);
 }
 /* Print PandP reconstruction parameters */
 void printReconParamsPandP(struct ReconParams *reconparams)
@@ -387,6 +390,7 @@ int ReadReconParams(
 	reconparams->StopThreshold=1.0;
 	reconparams->MaxIterations=20;
 	reconparams->Positivity=1;
+	reconparams->RelaxFactor=1.0;
 
 	reconparams->b_nearest=1.0;
 	reconparams->b_diag=0.707;
@@ -547,6 +551,14 @@ int ReadReconParams(
 			else
 				reconparams->Positivity = fieldval_d;
 		}
+		else if(strcmp(fieldname,"RelaxFactor")==0)
+		{
+			sscanf(fieldval_s,"%lf",&(fieldval_f));
+			if((fieldval_f <= 0.0) || (fieldval_f > 2.0))
+				fprintf(stderr,"Warning in %s: RelaxFactor outside valid range. Reverting to default value 1.0.\n",fname);
+			else
+				reconparams->RelaxFactor = fieldval_f;
+		}
 		else
 			fprintf(stderr,"Warning: unrecognized field \"%s\" in %s, line %d\n",fieldname,fname,i+1);
 
