@@ -107,7 +107,7 @@ void MBIRReconstruct(
     Aval_max_ptr = (float *) mget_spc(Nx*Ny,sizeof(float));
     if(Amatrix_fname != NULL)
     {
-        if(verboseLevel)
+        if(verboseLevel>1)
             fprintf(stdout,"Reading system matrix...\n");
         readAmatrix(Amatrix_fname, A_Padded_Map, Aval_max_ptr, &imgparams, &sinoparams, svpar);
     }
@@ -123,7 +123,7 @@ void MBIRReconstruct(
         sinoerr = proj_init;
     else
     {
-        if(verboseLevel)
+        if(verboseLevel>1)
             fprintf(stdout,"Projecting image...\n");
         sinoerr = (float *) mget_spc((size_t)Nz*Nvc,sizeof(float));
         SVproject(sinoerr,image,A_Padded_Map,Aval_max_ptr,imgparams,sinoparams,svpar,0);
@@ -286,8 +286,10 @@ void MBIRReconstruct(
     }
 
     // Limit threads for smaller problem size
+    // Want on average 1 thread per SV row/col within each slice block
+    // The /2 is on account of the phased checkerboard grouping
     int max_threads = omp_get_max_threads();
-    i = ((Nx < Ny) ? Nx : Ny) / (2*SVLength+1) * SV_per_Z;
+    i = ((Nx < Ny) ? Nx : Ny) / (2*SVLength-svpar.overlap) / 2 * SV_per_Z;
     max_threads = ( i < max_threads) ? i : max_threads;
 
     #pragma omp parallel num_threads(max_threads)
@@ -1119,7 +1121,7 @@ void forwardProject(
     Aval_max_ptr = (float *) mget_spc(imgparams.Nx*imgparams.Ny,sizeof(float));
     if(Amatrix_fname != NULL)
     {
-        if(verboseLevel)
+        if(verboseLevel>1)
             fprintf(stdout,"Reading system matrix...\n");
         readAmatrix(Amatrix_fname, A_Padded_Map, Aval_max_ptr, &imgparams, &sinoparams, svpar);
     }
@@ -1133,7 +1135,7 @@ void forwardProject(
     }
 
     /* Project */
-    if(verboseLevel)
+    if(verboseLevel>1)
     {
         if(backproject_flag)
             fprintf(stdout,"Back-projecting sinogram...\n");
