@@ -6,6 +6,8 @@ from psutil import cpu_count
 import shutil
 import numpy as np
 import os
+import sys
+import warnings
 import svmbir._utils as utils
 
 if os.environ.get('CLIB') =='CMD_LINE':
@@ -15,6 +17,7 @@ else:
 
 __svmbir_lib_path = os.path.join(os.path.expanduser('~'), '.cache', 'svmbir')
 
+
 def _svmbir_lib_path():
     """Returns the path to the cache directory used by svmbir
     """
@@ -100,7 +103,24 @@ def calc_weights(sino, weight_type ):
     return weights
 
 
-def auto_sigma_y(sino, weights, snr_db = 30.0, delta_pixel = 1.0, delta_channel = 1.0):
+def auto_max_resolutions(init_image) :
+    """Compute the automatic value of ``max_resolutions`` for use in MBIR reconstruction.
+
+    Args:
+        init_image (ndarray): Initial image for reconstruction.
+    Returns:
+        int: Automatic value of ``max_resolutions``.
+    """
+    # Default value of max_resolutions
+    max_resolutions = 2
+    if isinstance(init_image, np.ndarray) and (init_image.ndim == 3):
+        #print('Init image present. Setting max_resolutions = 0.')
+        max_resolutions = 0
+
+    return max_resolutions
+
+
+def auto_sigma_y(sino, weights, magnification = 1.0, delta_channel = 1.0, delta_pixel = 1.0, snr_db = 30.0 ) :
     """Compute the automatic value of ``sigma_y`` for use in MBIR reconstruction.
 
     Args:
@@ -109,12 +129,14 @@ def auto_sigma_y(sino, weights, snr_db = 30.0, delta_pixel = 1.0, delta_channel
         weights (ndarray):
             3D numpy array of weights with same shape as sino.
             The parameters weights should be the same values as used in svmbir reconstruction.
-        snr_db (float, optional):
-            [Default=30.0] Scalar value that controls assumed signal-to-noise ratio of the data in dB.
-        delta_pixel (float, optional):
-            [Default=1.0] Scalar value of pixel spacing in :math:`ALU`.
+        magnification (float):
+            (fan beam geometries only) Magnification factor = dist_source_detector/dist_source_isocenter.
         delta_channel (float, optional):
             [Default=1.0] Scalar value of detector channel spacing in :math:`ALU`.
+        delta_pixel (float, optional):
+            [Default=1.0] Scalar value of pixel spacing in :math:`ALU`.
+        snr_db (float, optional):
+            [Default=30.0] Scalar value that controls assumed signal-to-noise ratio of the data in dB.
 
 
     Returns:
@@ -129,8 +151,14 @@ def auto_sigma_y(sino, weights, snr_db = 30.0, delta_pixel = 1.0, delta_channel
     # convert snr to relative noise standard deviation
     rel_noise_std = 10 ** (-snr_db / 20)
 
+    # compute the default_pixel_pitch = the detector pixel pitch in the image plane given the magnification
+    default_pixel_pitch = delta_channel / magnification
+
+    # compute the image pixel pitch relative to the default.
+    pixel_pitch_relative_to_default = delta_pixel / default_pixel_pitch
+
     # compute sigma_y and scale by relative pixel and detector pitch
-    sigma_y = rel_noise_std * signal_rms * (delta_pixel / delta_channel) ** (0.5)
+    sigma_y = rel_noise_std * signal_rms * pixel_pitch_relative_to_default ** (0.5)
 
     if sigma_y > 0:
         return sigma_y
@@ -138,12 +166,14 @@ def auto_sigma_y(sino, weights, snr_db = 30.0, delta_pixel = 1.0, delta_channel
         return 1.0
 
 
-def auto_sigma_x(sino, delta_channel = 1.0, sharpness = 0.0 ):
+def auto_sigma_x(sino, magnification = 1.0, delta_channel = 1.0, sharpness = 0.0 ):
     """Compute the automatic value of ``sigma_x`` for use in MBIR reconstruction.
 
     Args:
         sino (ndarray):
             3D numpy array of sinogram data with shape (num_views,num_slices,num_channels).
+        magnification (float):
+            (fan beam geometries only) Magnification factor = dist_source_detector/dist_source_isocenter.
         delta_channel (float, optional):
             [Default=1.0] Scalar value of detector channel spacing in :math:`ALU`.
         sharpness (float, optional):
@@ -153,15 +183,17 @@ def auto_sigma_x(sino, delta_channel = 1.0, sharpness = 0.0 ):
     Returns:
         float: Automatic value of regularization parameter.
     """
-    return 0.2 * auto_sigma_prior(sino, delta_channel, sharpness)
+    return 0.2 * auto_sigma_prior(sino, magnification, delta_channel, sharpness)
 
 
-def auto_sigma_p(sino, delta_channel = 1.0, sharpness = 0.0 ):
+def auto_sigma_p(sino, magnification = 1.0, delta_channel = 1.0, sharpness = 0.0 ):
     """Compute the automatic value of ``sigma_p`` for use in proximal map estimation.
 
     Args:
         sino (ndarray):
             3D numpy array of sinogram data with shape (num_views,num_slices,num_channels).
+        magnification (float):
+            (fan beam geometries only) Magnification factor = dist_source_detector/dist_source_isocenter.
         delta_channel (float, optional):
             [Default=1.0] Scalar value of detector channel spacing in :math:`ALU`.
         sharpness (float, optional):
@@ -171,15 +203,17 @@ def auto_sigma_p(sino, delta_channel = 1.0, sharpness = 0.0 ):
     Returns:
         float: Automatic value of regularization parameter.
     """
-    return 1.0 * auto_sigma_prior(sino, delta_channel, sharpness)
+    return 1.0 * auto_sigma_prior(sino, magnification, delta_channel, sharpness)
 
 
-def auto_sigma_prior(sino, delta_channel = 1.0, sharpness = 0.0 ):
+def auto_sigma_prior(sino, magnification = 1.0, delta_channel = 1.0, sharpness = 0.0 ):
     """Compute the automatic value of prior model regularization term for use in MBIR reconstruction or proximal map estimation. This subroutine is called by ``auto_sigma_x`` in MBIR reconstruction, or ``auto_sigma_p`` in proximal map estimation.
 
     Args:
         sino (ndarray):
             3D numpy array of sinogram data with shape (num_views,num_slices,num_channels).
+        magnification (float):
+            (fan beam geometries only) Magnification factor = dist_source_detector/dist_source_isocenter.
         delta_channel (float, optional):
             [Default=1.0] Scalar value of detector channel spacing in :math:`ALU`.
         sharpness (float, optional):
@@ -195,7 +229,7 @@ def auto_sigma_prior(sino, delta_channel = 1.0, sharpness = 0.0 ):
     sino_indicator = _sino_indicator(sino)
 
     # Compute a typical image value by dividing average sinogram value by a typical projection path length
-    typical_img_value = np.average(sino, weights=sino_indicator) / (num_channels * delta_channel)
+    typical_img_value = np.average(sino, weights=sino_indicator) / (num_channels * delta_channel / magnification)
 
     # Compute sigma_p as the typical image value when sharpness==0
     sigma_prior = (2 ** sharpness) * typical_img_value
@@ -203,16 +237,9 @@ def auto_sigma_prior(sino, delta_channel = 1.0, sharpness = 0.0 ):
     return sigma_prior
 
 
-def auto_img_size(geometry, num_channels, delta_channel, delta_pixel, magnification=1.0):
+def auto_img_size(num_channels, delta_channel, delta_pixel, magnification=1.0):
     "Compute the default image size"
-
-    if geometry == 'parallel':
-        num_rows = int(np.ceil(num_channels * delta_channel / delta_pixel))
-    elif geometry == 'fan':
-        num_rows = int(np.ceil(num_channels * delta_channel / (delta_pixel*magnification) ))
-    else:
-        raise Exception('Unrecognized geometry {}'.format(geometry))
-
+    num_rows = int(np.ceil(num_channels * delta_channel / (delta_pixel*magnification) ))
     num_cols = num_rows
     return num_rows,num_cols
 
@@ -259,7 +286,7 @@ def recon(sino, angles,
           num_rows = None, num_cols = None, roi_radius = None,
           delta_channel = 1.0, delta_pixel = None, center_offset = 0.0,
           sigma_y = None, snr_db = 30.0, sigma_x = None, sigma_p = None, p = 1.2, q = 2.0, T = 1.0, b_interslice = 1.0,
-          sharpness = 0.0, positivity = True, max_resolutions = 0, stop_threshold = 0.02, max_iterations = 100,
+          sharpness = 0.0, positivity = True, relax_factor=1.0, max_resolutions = None, stop_threshold = 0.02, max_iterations = 100,
           num_threads = None, delete_temps = True, svmbir_lib_path = __svmbir_lib_path, object_name = 'object',
           verbose = 1) :
     """recon(sino, angles, geometry = 'parallel', **kwargs)
@@ -270,8 +297,12 @@ def recon(sino, angles,
         sino (ndarray): 3D sinogram array with shape (num_views, num_slices, num_channels).
         angles (ndarray): 1D view angles array in radians.
         geometry (string):
-            [Default='parallel'] Scanner geometry, either 'parallel' or 'fan'. Note for fan geometry
+            [Default='parallel'] Scanner geometry: 'parallel', 'fan-curved', or 'fan-flat'. Note for fan geometries
             the ``dist_source_detector`` and ``magnification`` arguments must be specified.
+        dist_source_detector (float):
+            (Required for fan beam geometries only) Distance from X-ray focal spot to detectors, in :math:`ALU`.
+        magnification (float):
+            (Required for fan beam geometries only) Magnification factor = dist_source_detector/dist_source_isocenter.
         weights (ndarray, optional): [Default=None] 3D weights array with same shape as sino.
         weight_type (string, optional): [Default="unweighted"] Type of noise model used for data.
             If the ``weights`` array is not supplied, then the function ``svmbir.calc_weights`` is 
@@ -294,17 +325,13 @@ def recon(sino, angles,
             If None, automatically set with auto_roi_radius().
             Pixels outside the radius roi_radius in the :math:`(x,y)` plane are disregarded in the reconstruction.
         delta_channel (float, optional): [Default=1.0] Scalar value of detector channel spacing in :math:`ALU`.
-        delta_pixel (float, optional): Scalar value of the spacing between image pixels in the 2D slice 
-            plane in :math:`ALU`. Defaults to ``delta_channel`` for ``parallel`` beam geometry, 
-            and ``delta_channel``/``magnification`` for ``fan`` geometry.
+        delta_pixel (float, optional): Scalar value of the spacing between image pixels in the 2D slice
+            plane in :math:`ALU`. Defaults to ``delta_channel`` for ``parallel`` beam geometry,
+            and ``delta_channel``/``magnification`` for fan beam geometries.
         center_offset (float, optional): [Default=0.0] Scalar value of offset from center-of-rotation.
-        dist_source_detector (float):
-            (Required, 'fan' geometry only) Distance from X-ray focal spot to detectors, in :math:`ALU`.
-        magnification (float):
-            (Required, 'fan' geometry only) Magnification factor = dist_source_detector/dist_source_isocenter.
         sigma_y (float, optional): [Default=None] Scalar value of noise standard deviation parameter.
             If None, automatically set with auto_sigma_y.
-        snr_db (float, optional): [Default=30.0] Scalar value that controls assumed signal-to-noise 
+        snr_db (float, optional): [Default=30.0] Scalar value that controls assumed signal-to-noise
             ratio of the data in dB. Ignored if sigma_y is not None.
         sigma_x (float, optional): [Default=None] Scalar value :math:`>0` that specifies the qGGMRF scale parameter.
             Ignored if prox_image is not None.
@@ -314,9 +341,9 @@ def recon(sino, angles,
             If None, automatically set with auto_sigma_p. Regularization should be controled with the 
             ``sharpness`` parameter, but ``sigma_p`` can be set directly by expert users.
         p (float, optional): [Default=1.2] Scalar value in range :math:`[1,2]` that specifies the qGGMRF shape parameter.
-        q (float, optional): [Default=2.0] Scalar value in range :math:`[p,1]` that specifies the qGGMRF shape parameter.
+        q (float, optional): [Default=2.0] Scalar value in range :math:`[p,2]` that specifies the qGGMRF shape parameter.
         T (float, optional): [Default=1.0] Scalar value :math:`>0` that specifies the qGGMRF threshold parameter.
-        b_interslice (float, optional): [Default=1.0] Scalar value :math:`>0` that specifies the interslice regularization.
+        b_interslice (float, optional): [Default=1.0] Non-negative scalar value that specifies the interslice regularization.
             The default value of 1.0 should be fine for most applications.
             However, b_interslice can be increased to values :math:`>1` in order to increase 
             regularization along the slice axis.
@@ -327,8 +354,11 @@ def recon(sino, angles,
         positivity (bool, optional): [Default=True] Boolean value that determines if positivity constraint 
             is enforced. The positivity parameter defaults to True; however, it should be changed to False 
             when used in applications that can generate negative image values.
-        max_resolutions (int, optional): [Default=0] Integer >=0 that specifies the maximum number of grid 
+        relax_factor (float, optional): [Default=1.0] Relaxation factor for pixel update. Valid range (0,2.0].
+            Values in (0,1) produce under-relaxation (smaller step size); Values in (1,2] produce over-relaxation.
+        max_resolutions (int, optional): [Default=None] Integer >=0 that specifies the maximum number of grid
             resolutions used to solve MBIR reconstruction problem.
+            If None, automatically set with auto_max_resolutions to 0 if inital image is provided and 2 otherwise.
         stop_threshold (float, optional): [Default=0.02] Scalar valued stopping threshold in percent.
             If stop_threshold=0.0, then run max iterations.
         max_iterations (int, optional): [Default=100] Integer valued specifying the maximum number of 
@@ -349,19 +379,38 @@ def recon(sino, angles,
         3D numpy array: 3D reconstruction with shape (num_slices,num_rows,num_cols) in units of :math:`ALU^{-1}`.
     """
 
+    # Issue notice of change of default regularization for 1 or 2 release cycles
+    #if snr_db is None:
+    #    if new_reg_defaults is True:
+    #        snr_db = 40.0
+    #    else:
+    #        snr_db = 30.0
+    #        sys.stderr.write("SVMBIR v0.3.0 NOTICE of pending change in regularization:\n")
+    #        sys.stderr.write("** Default image regularization and effect of 'sharpness' will change in the\n")
+    #        sys.stderr.write("** next release. To apply the changes immediately supply the following argument:\n")
+    #        sys.stderr.write("** svmbir.recon(...,new_reg_defaults=True)\n")
+
+    # Issue warning that 'fan' geometry will be removed in the future (last valid version is v0.2.9)
+    if geometry=='fan':
+        geometry = 'fan-curved'
+        warnings.warn("'fan' geometry will be removed in a future release. Fan beam geometry is now specified as either 'fan-curved' or 'fan-flat'. Defaulting to 'fan-curved'.",FutureWarning)
+
     # If not specified, then set number of threads = to number of processors
     if num_threads is None :
         num_threads = cpu_count(logical=False)
 
     # Test for valid sino and angles structure. If sino is 2D, make it 3D
     angles = utils.test_args_angles(angles)
-    sino = utils.test_args_sino(sino,angles)
+    sino = utils.test_args_sino(sino, angles)
     (num_views, num_slices, num_channels) = sino.shape
 
     # Tests parameters for valid types and values; print warnings if necessary; and return default values.
-    num_rows, num_cols, delta_pixel, roi_radius, delta_channel, center_offset = utils.test_args_geom(num_rows, num_cols, delta_pixel, roi_radius, delta_channel, center_offset)
-    sharpness, positivity, max_resolutions, stop_threshold, max_iterations = utils.test_args_recon(sharpness, positivity, max_resolutions, stop_threshold, max_iterations)
-    init_image, prox_image, init_proj, weights, weight_type = utils.test_args_inits(init_image, prox_image, init_proj, weights, weight_type)
+    num_rows, num_cols, delta_pixel, roi_radius, delta_channel, center_offset = utils.test_args_geom(
+        num_rows, num_cols, delta_pixel, roi_radius, delta_channel, center_offset)
+    sharpness, positivity, relax_factor, max_resolutions, stop_threshold, max_iterations = utils.test_args_recon(
+        sharpness, positivity, relax_factor, max_resolutions, stop_threshold, max_iterations)
+    init_image, prox_image, init_proj, weights, weight_type = utils.test_args_inits(
+        init_image, prox_image, init_proj, weights, weight_type)
     sigma_y, snr_db, sigma_x, sigma_p = utils.test_args_noise(sigma_y, snr_db, sigma_x, sigma_p)
     p, q, T, b_interslice = utils.test_args_qggmrf(p, q, T, b_interslice)
     num_threads, delete_temps, verbose = utils.test_args_sys(num_threads, delete_temps, verbose)
@@ -370,19 +419,23 @@ def recon(sino, angles,
     if geometry == 'parallel':
         dist_source_detector = 0.0
         magnification = 1.0
-    elif geometry == 'fan':
+    elif geometry=='fan-curved' or geometry=='fan-flat':
         if dist_source_detector is None or magnification is None:
-            raise Exception('For fanbeam geometry, need to specify dist_source_detector and magnification')
+            raise Exception('For fan beam geometries, need to specify dist_source_detector and magnification')
     else:
         raise Exception('Unrecognized geometry {}'.format(geometry))
 
+    # Set automatic value of max_resolutions
+    if max_resolutions is None :
+        max_resolutions = auto_max_resolutions(init_image)
+
     # Set automatic values of num_rows, num_cols, and roi_radius
     if delta_pixel is None:
         delta_pixel = delta_channel/magnification
     if num_rows is None:
-        num_rows,_ = auto_img_size(geometry, num_channels, delta_channel, delta_pixel, magnification)
+        num_rows,_ = auto_img_size(num_channels, delta_channel, delta_pixel, magnification)
     if num_cols is None:
-        _,num_cols = auto_img_size(geometry, num_channels, delta_channel, delta_pixel, magnification)
+        _,num_cols = auto_img_size(num_channels, delta_channel, delta_pixel, magnification)
     if roi_radius is None:
         roi_radius = auto_roi_radius(delta_pixel, num_rows, num_cols)
 
@@ -392,22 +445,22 @@ def recon(sino, angles,
 
     # Set automatic value of sigma_y
     if sigma_y is None:
-        sigma_y = auto_sigma_y(sino, weights, snr_db, delta_pixel=delta_pixel, delta_channel=delta_channel)
+        sigma_y = auto_sigma_y(sino, weights, magnification, delta_channel=delta_channel, delta_pixel=delta_pixel, snr_db=snr_db)
 
     # Set automatic value of sigma_x
     # if qGGMRF mode, then set sigma_x either using the provided value by user, or with auto_sigma_x
     if prox_image is None:
         if sigma_x is None:
-            sigma_x = auto_sigma_x(sino, delta_channel, sharpness)
+            sigma_x = auto_sigma_x(sino, magnification, delta_channel, sharpness)
     # if proximal map mode, then overwrite sigma_x with sigma_p
     else:
         if sigma_p is None:
-            sigma_p = auto_sigma_p(sino, delta_channel, sharpness)
+            sigma_p = auto_sigma_p(sino, magnification, delta_channel, sharpness)
         sigma_x = sigma_p
 
     # Reduce num_threads for positivity=False if problems size calls for it
-    #num_threads_max = max_threads(num_threads, num_slices, num_rows, num_cols, positivity=positivity)
-    #if num_threads_max < num_threads:
+    # num_threads_max = max_threads(num_threads, num_slices, num_rows, num_cols, positivity=positivity)
+    # if num_threads_max < num_threads:
     #    num_threads = num_threads_max
     os.environ['OMP_NUM_THREADS'] = str(num_threads)
     os.environ['OMP_DYNAMIC'] = 'true'
@@ -417,8 +470,8 @@ def recon(sino, angles,
                                        init_image=init_image, prox_image=prox_image, init_proj=init_proj,
                                        num_rows=num_rows, num_cols=num_cols, roi_radius=roi_radius,
                                        delta_channel=delta_channel, delta_pixel=delta_pixel, center_offset=center_offset,
-                                       sigma_y=sigma_y, snr_db=snr_db, sigma_x=sigma_x, p=p, q=q, T=T, b_interslice=b_interslice,
-                                       sharpness=sharpness, positivity=positivity, max_resolutions=max_resolutions,
+                                       sigma_y=sigma_y, sigma_x=sigma_x, p=p, q=q, T=T, b_interslice=b_interslice,
+                                       positivity=positivity, relax_factor=relax_factor, max_resolutions=max_resolutions,
                                        stop_threshold=stop_threshold, max_iterations=max_iterations, num_threads=num_threads,
                                        delete_temps=delete_temps, svmbir_lib_path=svmbir_lib_path, object_name=object_name,
                                        verbose=verbose)
@@ -427,9 +480,9 @@ def recon(sino, angles,
 
 
 
-def project(image, angles, num_channels, geometry = 'parallel',
+def project(image, angles, num_channels,
+            geometry = 'parallel', dist_source_detector = None, magnification = None,
             delta_channel = 1.0, delta_pixel = None, center_offset = 0.0, roi_radius = None,
-            dist_source_detector = None, magnification = None,
             num_threads = None, svmbir_lib_path = __svmbir_lib_path, delete_temps = True,
             object_name = 'object', verbose = 1):
     """project(image, angles, num_channels, geometry = 'parallel', **kwargs)
@@ -447,21 +500,21 @@ def project(image, angles, num_channels, geometry = 'parallel',
         num_channels (int):
             Number of sinogram channels.
         geometry (string):
-            [Default='parallel'] Scanner geometry, either 'parallel' or 'fan'. Note for fan geometry
+            [Default='parallel'] Scanner geometry: 'parallel', 'fan-curved', or 'fan-flat'. Note for fan geometries
             the ``dist_source_detector`` and ``magnification`` arguments must be specified.
+        dist_source_detector (float):
+            (Required for fan beam geometries only) Distance from X-ray focal spot to detectors, in :math:`ALU`.
+        magnification (float):
+            (Required for fan beam geometries only) Magnification factor = dist_source_detector/dist_source_isocenter.
         delta_channel (float, optional): [Default=1.0] Scalar value of detector channel spacing in :math:`ALU`.
         delta_pixel (float, optional): Scalar value of the spacing between image pixels in the 2D slice 
             plane in :math:`ALU`. Defaults to ``delta_channel`` for ``parallel`` beam geometry, 
-            and ``delta_channel``/``magnification`` for ``fan`` geometry.
+            and ``delta_channel``/``magnification`` for fan beam geometries.
         center_offset (float, optional):
             [Default=0.0] Offset from center-of-rotation in 'fractional number of channels' units.
         roi_radius (float, optional): [Default=None] Radius of relevant image region in :math:`ALU`.
             Pixels outside the radius are disregarded in the forward projection.
             If not given, the value is set with auto_roi_radius().
-        dist_source_detector (float):
-            (Required, 'fan' geometry only) Distance from X-ray focal spot to detectors, in :math:`ALU`.
-        magnification (float):
-            (Required, 'fan' geometry only) Magnification factor = dist_source_detector/dist_source_isocenter.
         num_threads (int, optional): [Default=None] Number of compute threads requested when executed.
             If None, num_threads is set to the number of cores in the system.
         svmbir_lib_path (string, optional):
@@ -500,13 +553,18 @@ def project(image, angles, num_channels, geometry = 'parallel',
     num_cols = image.shape[2]
     num_views = len(angles)
 
+    # Issue warning that 'fan' geometry will be removed in the future (last valid version is v0.2.9)
+    if geometry=='fan':
+        geometry = 'fan-curved'
+        warnings.warn("'fan' geometry will be removed in a future release. Fan beam geometry is now specified as either 'fan-curved' or 'fan-flat'. Defaulting to 'fan-curved'.",FutureWarning)
+
     # Geometry dependent settings
     if geometry == 'parallel':
         dist_source_detector = 0.0
         magnification = 1.0
-    elif geometry == 'fan':
+    elif geometry=='fan-curved' or geometry=='fan-flat':
         if dist_source_detector is None or magnification is None:
-            raise Exception('For fanbeam geometry, need to specify dist_source_detector and magnification')
+            raise Exception('For fan beam geometries, need to specify dist_source_detector and magnification')
     else:
         raise Exception('Unrecognized geometry {}'.format(geometry))
 
@@ -540,13 +598,12 @@ def project(image, angles, num_channels, geometry = 'parallel',
     return proj
 
 
-
-def backproject(sino, angles, geometry = 'parallel', num_rows=None, num_cols=None,
-            dist_source_detector = None, magnification = None,
+def backproject(sino, angles, num_rows=None, num_cols=None,
+            geometry = 'parallel', dist_source_detector = None, magnification = None,
             delta_channel = 1.0, delta_pixel = None, center_offset = 0.0, roi_radius = None,
             num_threads = None, svmbir_lib_path = __svmbir_lib_path, delete_temps = True,
             object_name = 'object', verbose = 1):
-    """backproject(sino, angles, geometry = 'parallel', **kwargs)
+    """backproject(sino, angles, **kwargs)
 
     Compute 3D back-projection.
 
@@ -556,23 +613,22 @@ def backproject(sino, angles, geometry = 'parallel', num_rows=None, num_cols=Non
         angles (ndarray):
             1D numpy array of view angles in radians.
             'angles[k]' is the angle in radians for view :math:`k`.
-        geometry (string):
-            [Default='parallel'] Scanner geometry, either 'parallel' or 'fan'. Note for fan geometry
-            the ``dist_source_detector`` and ``magnification`` arguments must be specified.
         num_rows (int, optional):
             [Default=num_channels] Integer number of output image rows.
         num_cols (int, optional):
             [Default=num_channels] Integer number of output image columns.
+        geometry (string):
+            [Default='parallel'] Scanner geometry: 'parallel', 'fan-curved', or 'fan-flat'. Note for fan geometries
+            the ``dist_source_detector`` and ``magnification`` arguments must be specified.
         dist_source_detector (float):
-            (Required, 'fan' geometry only) Distance from X-ray focal spot to detectors, in :math:`ALU`.
+            (Required for fan beam geometries only) Distance from X-ray focal spot to detectors, in :math:`ALU`.
         magnification (float):
-            (Required, 'fan' geometry only) Magnification factor = dist_source_detector/dist_source_isocenter.
+            (Required for fan beam geometries only) Magnification factor = dist_source_detector/dist_source_isocenter.
         delta_channel (float, optional):
             [Default=1.0] Detector channel spacing in :math:`ALU`.
-        delta_pixel (float, optional):
-            Size of image pixels in the 2D slice plane in :math:`ALU`.
-            Defaults to ``delta_channel`` for ``parallel`` beam geometry, 
-            and ``delta_channel``/``magnification`` for ``fan`` geometry.
+        delta_pixel (float, optional): Scalar value of the spacing between image pixels in the 2D slice 
+            plane in :math:`ALU`. Defaults to ``delta_channel`` for ``parallel`` beam geometry, 
+            and ``delta_channel``/``magnification`` for fan beam geometries.
         center_offset (float, optional):
             [Default=0.0] Offset from center-of-rotation in 'fractional number of channels' units.
         roi_radius (float, optional): [Default=None] Radius of relevant image region in :math:`ALU`.
@@ -609,22 +665,27 @@ def backproject(sino, angles, geometry = 'parallel', num_rows=None, num_cols=Non
     if num_views != len(angles):
         raise Exception('svmbir.backproject(): angles and sinogram arrays have conflicting sizes')
 
+    # Issue warning that 'fan' geometry will be removed in the future (last valid version is v0.2.9)
+    if geometry=='fan':
+        geometry = 'fan-curved'
+        warnings.warn("'fan' geometry will be removed in a future release. Fan beam geometry is now specified as either 'fan-curved' or 'fan-flat'. Defaulting to 'fan-curved'.",FutureWarning)
+
     # Geometry dependent settings
     if geometry == 'parallel':
         dist_source_detector = 0.0
         magnification = 1.0
-    elif geometry == 'fan':
+    elif geometry=='fan-curved' or geometry=='fan-flat':
         if dist_source_detector is None or magnification is None:
-            raise Exception('For fanbeam geometry, need to specify dist_source_detector and magnification')
+            raise Exception('For fan beam geometries, need to specify dist_source_detector and magnification')
     else:
         raise Exception('Unrecognized geometry {}'.format(geometry))
 
     if delta_pixel is None:
         delta_pixel = delta_channel/magnification
     if num_rows is None:
-        num_rows,_ = auto_img_size(geometry, num_channels, delta_channel, delta_pixel, magnification)
+        num_rows,_ = auto_img_size(num_channels, delta_channel, delta_pixel, magnification)
     if num_cols is None:
-        _,num_cols = auto_img_size(geometry, num_channels, delta_channel, delta_pixel, magnification)
+        _,num_cols = auto_img_size(num_channels, delta_channel, delta_pixel, magnification)
     if roi_radius is None:
         roi_radius = auto_roi_radius(delta_pixel, num_rows, num_cols)
 
